
data {
    int N;		//	The number of trials
    array[N] int Res;	//	Responses:  
    //	1 denotes -, 2 denotes ?, 3 denotes +
    array[N] real X;	//	Stimuli
    real d_mid;         //      Midpoint of the stimuli
    real d_sd;          //      Rough dispersion measure of the stimuli
}

parameters {
    real<lower = 0.0, upper = 1.0> v_sgm;
    real v_C1;
    real<lower = 0.0> v_C2;
}

transformed parameters {
    real<lower = 0.0> sgm;
    real C1;
    real C2;
    array[N] vector[3] p;		//	Probabilities for X[N]
    
    sgm = v_sgm * d_sd * 10.0;
    C1 = v_C1 * d_sd * 10.0 + d_mid;
    C2 = C1 + v_C2 * d_sd * 10.0;
    for (i in 1:N){
        p[i][1] = 1 - normal_cdf((X[i] - C1) / sgm | 0, 1);
        p[i][2] = normal_cdf((X[i] - C1) / sgm | 0, 1)
                    - normal_cdf((X[i] - C2) / sgm | 0, 1);
        p[i][3] = normal_cdf((X[i] - C2) / sgm | 0, 1);
    }
}

model {
    v_sgm ~  exponential(0.1); 
    v_C1 ~ normal(0.0, 10.0); 
    v_C2 ~ exponential(0.1);
    for (i in 1:N)
        Res[i] ~ categorical(p[i]);
}

generated quantities {
    real pse;
    real jnd;
    pse = (C1 + C2) / 2;
    jnd = 0.6745 * sgm;
}
